import base64
from distutils.log import Log

import grpc
import time
from collections import defaultdict
from typing import Any, Callable, Dict, Iterator, Union
from requests import get
import base64
import uuid
from logging import DEBUG, INFO, getLogger, basicConfig

from kaspy.streams import P2PRequestStream, RequestStream, SubcribeStream
from kaspy.network.node import UNKNOWEN, Node, node_acquirer
from kaspy.protos.messages_pb2 import KaspadMessage, _KASPADMESSAGE
from kaspy.protos.messages_pb2_grpc import P2PStub, RPCStub
from kaspy.defines import MAINNET, P2P_DEF_PORTS, P2P_SERVICE, RPC_DEF_PORTS, RPC_SERVICE, CONNECTED, CLOSED, DISCONNECTED, USER_AGENT
from kaspy.log_handler.log_messages import client as cli_lm
from kaspy.utils.version_comparer import version as ver
from kaspy.excepts.exceptions import CLientClosed, ClientDisconnected, CommandIsNotSubcribable, InvalidCommand, RPCResponseException, RPCServiceUnavailable, SubscriptionCannotBeUnsubscribed


basicConfig(level=INFO)
basicConfig(level=DEBUG)
LOG = getLogger('[KASPA_CLI]')


class _KaspaClient(object): None #just a class towards wich all clients can be tested

       
class BaseClient(_KaspaClient):
    
    def __init__(self) -> None:
        self.node = Node
        self.service = None
        self._is_connected = lambda : True if self._chan else False
        self.server_status = str #hold server status from grpc.RpcErrors
        self.client_status = str #hold client status : CONNECTED, DISCONNECTED or CLOSED
        self._subscriptions = defaultdict(dict) #hold subscription streams
        self.request_stream = RequestStream
        self.restablish_new_connection  = None
        self._retry_count = None
        self._retry_wait = None
        self._auto_conn_params = None
        self.service
    
    # display node infos through the client:
    
    @property
    def host_latency(self):
        return self.node.latency(5) #not sure what is a good default but we get stuck if we don't supply and port is closed
    
    @property 
    def host_subnetwork(self):
        return self.node.network
    
    @property
    def host_version(self):
        return self.node.version
    
    @property
    def host(self):
        return self.node.__str__()
    
    @property
    def host_port(self):
        return self.node.port
    
    @property
    def host_ip(self):
        return self.node.ip
    
    
    # connecting opperations
    
    def reconnect(self):
        
        self._activate_stream.set()

    def connect(self, host: str, port: Union[int, str], idle_timeout: Union[float, int, None] = None, 
                retry_count: float = None, retry_wait:float = None, max_receive_size = (1024**2)*4) -> None:
        self.client_status = CONNECTED
        self._retry_count = retry_count if retry_count else 0
        self._retry_wait = retry_wait if retry_wait else 0
        self.node = Node(host, port)
        LOG.info(cli_lm.CONN_ESTABLISHING(self.node))
        self.request_stream = P2PRequestStream(node=self.node, stub=self._get_service_stub(), idle_timeout=idle_timeout, max_receive_size=max_receive_size)
        self.request_stream.start()
        LOG.info(cli_lm.CONN_ESTABLISHED(self.node))
    
    def auto_connect(*args, **kwargs) -> NotImplementedError:
        '''**NotImplemented** 
        
        The procdure required to filter for nodes between RPC and P2P are too different to warrent `auto_connect` on the BaseClient.
        use `auto_connect` with `RPCClient`, `P2PClient`, or `DualClient` instead'''
        raise NotImplementedError 
    
    
    # disconnecting /closing opperations
    
    def disconnect(self) -> None:
        for sub in self._subscriptions.values():
            sub.disconnect()
        self.client_status = DISCONNECTED
        self.request_stream.disconnect()
    
    def close(self) -> None:
        self.close_all_streams()
        self.request_stream.close()
    
    # Subscription operations 
    def _is_subscription(self, command: str):
        if command.startswith('notify'): 
            return True
        else: 
            return False
    
    def _sub_req_to_sub_message(self, command: str):
        sub_msg =  command.replace('Request', 'Notification')[6:]
        return sub_msg[0].lower() + sub_msg[1:]
    
    def subscribe(self, command: str,  callback: Callable[[dict], Any], payload: Union[dict, str, None] = None, idle_timeout: Union[float, None] = None) -> None:
        #if self._is_subscription_request(command):
        self._subscriptions[command] = SubcribeStream(self.node, command, payload, callback, 
                                                          self._get_service_stub(), idle_timeout=idle_timeout)
        self._subscriptions[command].start()
        #else:
            #raise CommandIsNotSubcribable(self.node, command)
    
    def unsubscribe(self, command: str) -> None:
        self._subscriptions[command].close()
        del self._subscriptions[command]
    
    def close_all_streams(self):
        for sub in self._subscriptions.values():
            sub.close()
        self._subscriptions = defaultdict(dict)
    
    # checks
    def _is_subscription_request(self, command: str):
        return command.startswith('notify')
    
    def _verify_connection(self, command : Union[str, None]) -> Union[bool, Exception]:
        if self.client_status == CONNECTED:
            return True
        elif self.client_status == DISCONNECTED:
            raise ClientDisconnected(self.node, command)
        elif self.client_status == CLOSED:
            raise CLientClosed(self.node, command)
        
    # Serializations

    def _serialize_response_to_json(self, response : KaspadMessage) -> str:
        raise NotImplementedError
    
    # helpers
    
    def _get_message_name(self, serialized_msg : dict):
        return next(iter(serialized_msg.keys()))
    
    def _get_service_stub(self):
        return RPCStub if self.service == RPC_SERVICE else P2PStub
    
    # standard interactions
    
    def send(self, command : str, payload : Union[dict, str, None] = None) -> None:
        self._verify_connection(command)
        LOG.info(cli_lm.MSG_SENDING(command, self.node))
        self.request_stream.put((command, payload))
    
    def recv(self, timeout: Union[float, int, None] = 2) -> Iterator[Union[dict, str]]:
        try:
            return self.request_stream.get(timeout)
        except grpc.RpcError as e:
            self._response_error_handler(str(e.code()), e.details())
        except TimeoutError as te:
            self._retry_connection(te)
            
    
    def request(self, command : str, payload: Union[dict, str, None] = None, timeout: Union[float, int, None] = None) -> Union[dict, str]:
        self.send(command, payload)
        resp = self.recv(timeout)
        LOG.info(cli_lm.MSG_RECIVED(
            self._get_message_name(resp),
            command,
            self.node
                    ))
        return resp
        
    # some funcs to query for server info
    
    def kaspa_open_services(self):
        '''query default open ports for all subnetworks and services'''
        self._verify_connection() # this goes through sockets, so needs own _verify connection
        raise NotImplementedError
    
    def kaspad_check_port(self, timeout: Union[float, None]) -> Union[float, None]:
        '''checks port is open within timeout -> returns latency, or none if port is not reachable'''
        self._verify_connection('latency') #this goes through sockets, so needs own _verify connection
        return self.node.latency(timeout)
    
    # Error handling:
    def _retry_connection(self, err, counter = 0):
        if counter == self._retry_count:
            if self.restablish_new_connection:
                self.auto_connect(*self._auto_conn_params) #save input from last auto_connect call
            raise err
        time.sleep(self._retry_wait)
        self.connect(self.node.ip, self.node.port)
        try:
            self.request('getInfoRequest') # test the connection
        except Exception as e:
            LOG.debug(e)
            self._retry_connection(err, counter=counter+1)

    def _response_error_handler(self, code : str, details : str):
        #for now raise until we have proper error handling. 
        if code == 'UNAVAILABLE': #only real exception I am catching during testing, I doubt there is anything we can do on the client side. 
            err = RPCServiceUnavailable(self.node, code, details)
            if self._retry_count:
                LOG.debug(err)
                self._retry_connection(err)
            else:
                raise err
        #will add error handling as issues arise - for now I will leave it as is.
        else:
            err = RPCResponseException(self.node, code, details)
            if self._retry_count:
                LOG.debug(err)
                self._retry_connection(err)
            raise err
    
    def _requests_error_handler(self, command : str, payload : dict):
        #for now raise until we have proper error handling. 
        raise InvalidCommand(self.node, command) 
    
class RPCClient(BaseClient):
    def __init__(self) -> None:
        '''kaspa client for RPC services'''
        super().__init__()
        self.service = RPC_SERVICE
        self.request_stream = RequestStream
    
    @property
    def host_untxoindex(self):
        return self.node.utxoindex
    
    # some more funcs to query for RPC server info
    
    def kaspad_version(self, timeout) -> ver:
        '''Query the kaspad version the host is running''' 
        if str(self.node.version) == UNKNOWEN:
            self.node.version = ver.parse_from_string(self.request('getInfoRequest', timeout=timeout)['getInfoResponse']['serverVersion'])
        return self.node.version
        
    def kaspad_network(self, timeout) -> str:
        '''Querx the kaspad network the host is running'''
        if str(self.node.network) == UNKNOWEN:
            self.node.network = self.request('getCurrentNetworkRequest', timeout=timeout)['getCurrentNetworkResponse']['currentNetwork'].lower()
        return self.node.network
    
    def kaspad_utxoindex(self, timeout):
        try:
                return self.request('getInfoRequest', {})['getInfoResponse']['isUtxoIndexed']
        except:
                return false

    def auto_connect(self, min_kaspad_version: Union[ver, str, None] = None, subnetwork: Union[str, None] = MAINNET,
                    conn_timeout: Union[float, None] = 3, idel_timeout: float = None, max_latency: Union[float, None] =  None, 
                    retry_count = None, retry_wait = None, new_conn_on_err: bool = False, utxoindex: bool = False, max_receive_size=(1024**2)*4) -> None:
        '''auto connect to a RPC node'''
        if new_conn_on_err:
            self._auto_conn_params = tuple(locals().values(),)[1:] # for possible later use in self._retry_connection
        port = RPC_DEF_PORTS[subnetwork]
        self.restablish_new_connection = new_conn_on_err
        for node in node_acquirer.yield_open_nodes(port = port):
            self.connect(node.ip, port, idel_timeout, retry_count, retry_wait, max_receive_size=max_receive_size)
            latency = self.kaspad_check_port(min(filter(bool, [conn_timeout, max_latency]), default=None))
            if not latency:
                self.close()
                continue
            if latency:
                if max_latency:
                    if latency > max_latency:
                        self.close()
                        continue
            try:
                if utxoindex == True:
                    if not self.kaspad_utxoindex(conn_timeout):
                        self.close()
                        continue
                if subnetwork:
                    if self.kaspad_network(conn_timeout) != subnetwork:
                        self.close()
                        continue
                if min_kaspad_version:
                    if isinstance(min_kaspad_version, str): 
                        min_kaspad_version = ver.parse_from_string(min_kaspad_version)
                    if self.kaspad_version(conn_timeout) < min_kaspad_version:
                        self.close()
                        continue
            except (RPCServiceUnavailable, TimeoutError) as e:
                LOG.debug(e)
                self.close()
                continue
            break
        
class P2PClient(BaseClient):
    '''
    still need to read up on p2p message docs if i were to find them, or read through the kaspad codebase
    --> VersionMessage seems promising for all infos needed to auto_connect.
    --> perform handshake 
    --> intiate a heartbeats to signal we are still alive  
    '''
    
    def __init__(self) -> None:
        '''kaspa client for P2P services'''
        super().__init__()
        self.service = P2P_SERVICE
        self.id = str(uuid.uuid4())
        self.request_stream = P2PRequestStream
        self.external_ip =  get('https://api.ipify.org').text 
        raise NotImplementedError # unstable, unfinished
        
    # some more funcs to query for P2P server info
    
    def _byte_ip_to_ip(self, ip):
        hex_ip = base64.b64decode(ip).hex()
        return ':'.join([hex_ip[i:i+4] for i in range(0 ,len(hex_ip), 4)])
        
    def _heartbeat(self):
        raise NotImplementedError
    
    def _handshake(self, timeouts):
        # Perform handshake according to https://github.com/kaspanet/docs/blob/main/Reference/API/P2P.md
        # note above is outdated
        version_msg = self.recv(timeouts)['version'] # get version msg from kaspad
        self.send('verack')# Verify we got their version
        self.node.protocol = ver(version_msg['protocolVersion'], 0, 0)
        self.node.version = ver.parse_from_string(version_msg['userAgent'].rsplit('/')[-2])
        self.node.network = version_msg['network'].split('-')[-1]
        my_version = {
            'protocolVersion': version_msg['protocolVersion'], 
            'services': '37', 
            'timestamp': f'{int(time.time()*1000)}',
            'address': {
                'timestamp': f'{int(time.time()*1000)}', 
                'ip': self.external_ip, 
                'port': version_msg['address']['port']
                }, 
            'id': self.id,
            'userAgent': USER_AGENT, # NKOTB
            'network': version_msg['network'], 
                }
        #self.send('ready')
        #print('1.1 ', self.recv())
        self.send('version', my_version) #send our version
        self.recv() # get their verification
        self.send('ready') #send our ready
        self.send('requestAddresses') #ask for addresses
        self.recv() #get their ready
        self.recv() #get their addresses
        # now we have completed the handshake...
        pass
    
    def connect(self, host : str , port : int, filter_inv: bool = True, handshake_timeouts: float =None):
        super().connect(host, port)
        if filter_inv:
            self.request_stream.filter = True
        else:
            self.request_stream.filter = False
        self._handshake(handshake_timeouts)
    
    def auto_connect(self, disable_relay_tx: bool = True, subnetwork: Union[str, None] = MAINNET,
            min_kaspad_version: Union[ver, str, None] = None, timeout: Union[float, None] = 5, 
            max_latency: Union[float, None] =  None, new_conn_on_err: bool = False, max_receive_size = (1024**2)*4):
        '''auto connect to a P2P node'''
        port = P2P_DEF_PORTS[subnetwork]
        self.restablish_new_connection = new_conn_on_err
        for node in node_acquirer.yield_open_nodes(port = port):
            try:
                latency = self.kaspad_check_port(min(filter(bool, [timeout, max_latency]), default=None))
                if not latency: 
                    LOG.info("no latency")
                    continue
                if latency:
                    if max_latency:
                        if latency > max_latency:
                            LOG.info("low latency")
                            continue
                self.connect(node.ip, port, disable_relay_tx, timeout, max_receive_size)
            except (RPCServiceUnavailable, TimeoutError) as e:
                LOG.debug(e)
                continue
            if subnetwork:
                if subnetwork != self.node.network:
                    Log.info("wrong network")
                    continue
            if min_kaspad_version:
                if isinstance(min_kaspad_version, str):
                    min_kaspad_version = ver.parse_from_string(self.node.version)
                if self.node.version < min_kaspad_version:
                    LOG.info("old node")
                    continue
            break

class DualClient(_KaspaClient):
        
    '''Unsure if it will be ever implemented: idea is that it connects to both rpc and p2p ports, and perserves request -> response order'''
    
    def __init__(self) -> None:
        raise NotImplementedError #only barebones idea.
        self.rpc_client = RPCClient
        self.p2p_client = P2PClient
    
    @property
    def client_status(self):
        if self.rpc_client.client_status == self.p2p_client.client_status:
            return self.rpc_client.client_status
        else:
            raise Exception       
    
    def _request_to_service(self, request: str) -> str:
        if _KASPADMESSAGE.fields_by_name[request].number < 50:
            return P2P_SERVICE
        elif _KASPADMESSAGE.fields_by_name[request].number > 1000:
            return RPC_SERVICE
    
    def connect(self, host : str, rpc_port : Union[str, int], p2p_port: Union[str,int]) -> None:
        self.rpc_client.connect(host=host, port=int(rpc_port))
        self.p2p_client.connect(host=host, port=int(p2p_port))
    
    def disconnect(self):
        self.rpc_client.disconnect()
        self.p2p_client.disconnect()
    
    def close(self):
        self.rpc_client.close()
        self.p2p_client.close()
        
    def send():
        raise NotImplementedError
    
    def recv():
        raise NotImplementedError
    
    def auto_connect(self, min_kaspad_version: Union[ver, str, None] = None, min_protocol_version: Union[ver, str, None] = None,
                     subnetwork: Union[str, None] = None, timeout: Union[float, None] = None, 
                     max_latency: Union[float, None] =  None) -> None:
        raise NotImplementedError
    


from kaspy.protos.messages_pb2_grpc import RPCStub, P2PStub
from kaspy.protos.messages_pb2 import _KASPADMESSAGE, KaspadMessage
from kaspy.network.node import Node
from kaspy.defines import CONNECTED, DISCONNECTED, CLOSED

import grpc
import json
import sys
from queue import Empty, SimpleQueue
from google.protobuf import json_format
from typing import Any, Callable, Union
from threading import Event, Thread
from .excepts.exceptions import InvalidCommand

grpc.max_send_message_length = -1
grpc.max_receive_message_length = -1

class BaseStream:
    
    def __init__(self, node: Node, stub: Union[RPCStub, P2PStub], idle_timeout: float = None, max_receive_size=(1024**2)*4):
        self._conn = grpc.insecure_channel(
            f'{node}',
            options = [
                ('grpc.max_send_message_length', -1),
                ('grpc.max_receive_message_length', max_receive_size)
                    ]
                )
        self._stub = stub(self._conn)
        self._halt = Event()
        self._idle_timeout = idle_timeout
        self._inputs = SimpleQueue()
        self.status = CONNECTED

    def start(self):
        Thread(target=self.run, daemon=True).start()
    
    def run(self):
        self.status = CONNECTED
        self._halt.set()
        self.switch()
    
    def switch(self):
        self._halt.wait()
        try:
            for resp in self._stub.MessageStream((inp for inp in self.loop()), timeout=self._idle_timeout):
                resp = self._serialize_response_to_dict(resp)
                self.process_output(resp)
        except (grpc.RpcError, StopIteration) as e:
            if self.status == CLOSED:
                pass
            else:
                raise e
    
    def loop(self):
        while True:
            inp =  self._inputs.get()
            if inp == DISCONNECTED:
                self.switch()
            else:
                yield self._serialize_request(*inp)
    
    def disconnect(self):
        self._halt.clear()
        self._inputs.put(DISCONNECTED)
        pass
    
    def reconnect(self):
        self.status = CONNECTED
        self._halt.set()
    
    def close(self):
        self.status = CLOSED
        self._conn.close()    

    def process_output(self, output):
        raise NotImplementedError
    
    def _serialize_request(self, command : str, payload : Union[dict, str, None] = {}) -> KaspadMessage:
        if payload is None: payload = {}
        if command == _KASPADMESSAGE.fields_by_name[command].name: # this is important so we don't execute arbitary python code in this function
            kaspa_msg = KaspadMessage()
            app_msg = eval(f'kaspa_msg.{command}') #should not use eval - but seems like the easiest way for now.
            if payload:
                if isinstance(payload, dict):
                    json_format.ParseDict(payload, app_msg)
                if isinstance(payload, str):
                    json_format.Parse(payload, app_msg)
            app_msg.SetInParent()
            return kaspa_msg
        else:
            raise InvalidCommand(self.node, command)
    
    def _serialize_response_to_dict(self, response: KaspadMessage) -> dict:
        return json_format.MessageToDict(response)

class RequestStream(BaseStream):
    
    def __init__(self, node: Node, stub: Union[RPCStub, P2PStub], idle_timeout: float = None, filter: set = set([]),  max_receive_size=(1024**2)*4):
        super().__init__(node, stub, idle_timeout=idle_timeout,  max_receive_size=max_receive_size)
        self._outputs = SimpleQueue()
        self.filter = filter
        
    def get(self, timeout: Union[int, float, None] = None) -> KaspadMessage:
        try:
            return self._outputs.get(timeout=timeout)
        except Empty:
            raise TimeoutError
    
    def put(self, input):
        self._inputs.put(input)
    
    def process_output(self, output):
        test = next(iter(output.keys()))
        if test in self.filter:
            pass
        else:
            self._outputs.put(output)

class SubcribeStream(BaseStream):
    
    def __init__(self, node, command: str, payload: Union[None,dict], callback: Callable[[dict], Any], stub: Union[RPCStub, P2PStub], idle_timeout: float = None, max_receive_size=(1024**2)*4):
        super().__init__(node=node, stub=stub, idle_timeout=idle_timeout, max_receive_size=max_receive_size)
        self.subscription = (command, payload)
        sub_msg = command[6:].replace('Request', 'Notification')
        self._sub_msg = sub_msg[0].lower() + sub_msg[1:]
        self._callback = callback
        self._hash =  hash(f'{self._sub_msg}')
        
    def run(self):
        self._halt.set()
        self._inputs.put(self.subscription)
        self.switch()
    
    def _send_thread_to_callback(self, output):
        Thread(target=self._callback, args=(output,), daemon=True).start()
        
    def process_output(self, output):
        if next(iter(output.keys())) == self._sub_msg:
            self._send_thread_to_callback(output)
            
class P2PRequestStream(BaseStream):
    
    def __init__(self, node: Node, stub: Union[RPCStub, P2PStub], idle_timeout: float = None, filter_inv = True, max_receive_size=(1024**2)*4):
        super().__init__(node, stub, idle_timeout=idle_timeout, max_receive_size=max_receive_size)
        self._outputs = SimpleQueue()
        self.filter = filter_inv
        
    def get(self, timeout: Union[int, float, None] = None) -> KaspadMessage:
        try:
            return self._outputs.get(timeout=timeout)
        except Empty:
            raise TimeoutError
    
    def put(self, input):
        self._inputs.put(input)
    
    def process_output(self, output):
        if self.filter and any(x in ('invRelayBlock', 'invTransactions') for x in output.keys()):
            return None
        else:
            self._outputs.put(output)


from logging import getLogger, basicConfig, INFO
from typing import Set, Union, Iterator
import socket
import time
from kaspy.log_handler.log_messages import network as net_lm
from kaspy.defines import MAINNET, P2P_DEF_PORTS, RPC_DEF_PORTS

basicConfig(level=INFO)
LOG = getLogger('[KASPA_NOD]')

UNKNOWEN = 'unknown'

class query_node:
    '''some socket things to navigate and check connectivity'''
    
    @classmethod
    def port_open(cls, ip : str, port : Union[int, str], timeout: float) -> Union[float, None]:
        LOG.info(net_lm.LATENCY_QUERY(f'{ip}:{port}'))
        sock = socket.socket(socket.AF_INET, socket. SOCK_STREAM)
        sock.settimeout(timeout)
        try:
            start = time.perf_counter()
            sock.connect((ip, int(port)))
            latency = time.perf_counter() - start
            LOG.info(net_lm.CHECK_LATENCY_STATUS_DELAY(f'{ip}:{port}', latency))
        except Exception as e:
            LOG.debug(e)
            LOG.info(net_lm.CHECK_LATENCY_STAUTS_NONE(f'{ip}:{port}'))
            latency= None
        finally: sock.close()
        return latency            
    
    @classmethod
    def connected_peers(cls, ip : str, port : Union[str, int]) -> Union[Set[str], None]:
        try:
            return set([f'{addr[-1][0]}:{port}' for addr in socket.getaddrinfo(host=ip, port=int(port))])
        except Exception as e:
            LOG.debug(e)
            return None

class Node:
    
    def __init__(self, ip: str, port: Union[str, int]) -> None:
        self.ip = ip 
        self.port = port
        self.network = UNKNOWEN
        self.version = UNKNOWEN
        self.protocol = UNKNOWEN
        self.utxoindex = UNKNOWEN
    
    def port_open(self, timeout :float) -> bool:
        return bool(self.latency(timeout))
    
    def latency(self, timeout :float):
        return query_node.port_open(self.ip, self.port, timeout)
    
    def __hash__(self) -> int:
        return hash(f'{self}')
    
    def __str__(self) -> str:
        return f'{self.ip}:{self.port}' #keep for comaptibility with client class until dual RPC and P2P connections are dealt with
    
class node_acquirer:
    
    dns_seed_servers = [
        f"mainnet-dnsseed.daglabs-dev.com",
        f"mainnet-dnsseed-1.kaspanet.org",
        f"mainnet-dnsseed-2.kaspanet.org",
        f"dnsseed.cbytensky.org",
        f"seeder1.kaspad.net",
        f"seeder2.kaspad.net",
        f"seeder3.kaspad.net",
        f"seeder4.kaspad.net",
        f"kaspadns.kaspacalc.net"
    ]
    
    @classmethod
    def yield_open_nodes(cls, port: Union[str, int]) -> Iterator[Node]:
        LOG.info(net_lm.SCANNING)
        while True:
            scanned = set()
            for dns_server in cls.dns_seed_servers:
                addresses = query_node.connected_peers(ip=dns_server, port=RPC_DEF_PORTS[MAINNET])
                if not addresses: continue
                addresses = addresses - scanned
                LOG.info(net_lm.SCANNING_RETRIVED_NODES_FROM(dns_server, addresses))
                if not addresses: continue
                for addr in addresses:
                    node = Node(*addr.rsplit(':', 1))
                    LOG.info(net_lm.CHECK_NODE(node))
                    if node in scanned: continue
                    scanned.add(node)
                    yield node



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\trpc.proto\x12\tprotowire\"\x1b\n\x08RPCError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9b\x01\n\x08RpcBlock\x12)\n\x06header\x18\x01 \x01(\x0b\x32\x19.protowire.RpcBlockHeader\x12/\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x19.protowire.RpcTransaction\x12\x33\n\x0bverboseData\x18\x03 \x01(\x0b\x32\x1e.protowire.RpcBlockVerboseData\"\x9e\x02\n\x0eRpcBlockHeader\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x30\n\x07parents\x18\x0c \x03(\x0b\x32\x1f.protowire.RpcBlockLevelParents\x12\x16\n\x0ehashMerkleRoot\x18\x03 \x01(\t\x12\x1c\n\x14\x61\x63\x63\x65ptedIdMerkleRoot\x18\x04 \x01(\t\x12\x16\n\x0eutxoCommitment\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\x12\x0c\n\x04\x62its\x18\x07 \x01(\r\x12\r\n\x05nonce\x18\x08 \x01(\x04\x12\x10\n\x08\x64\x61\x61Score\x18\t \x01(\x04\x12\x10\n\x08\x62lueWork\x18\n \x01(\t\x12\x14\n\x0cpruningPoint\x18\x0e \x01(\t\x12\x11\n\tblueScore\x18\r \x01(\x04\",\n\x14RpcBlockLevelParents\x12\x14\n\x0cparentHashes\x18\x01 \x03(\t\"\xfb\x01\n\x13RpcBlockVerboseData\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\ndifficulty\x18\x0b \x01(\x01\x12\x1a\n\x12selectedParentHash\x18\r \x01(\t\x12\x16\n\x0etransactionIds\x18\x0e \x03(\t\x12\x14\n\x0cisHeaderOnly\x18\x0f \x01(\x08\x12\x11\n\tblueScore\x18\x10 \x01(\x04\x12\x16\n\x0e\x63hildrenHashes\x18\x11 \x03(\t\x12\x1b\n\x13mergeSetBluesHashes\x18\x12 \x03(\t\x12\x1a\n\x12mergeSetRedsHashes\x18\x13 \x03(\t\x12\x14\n\x0cisChainBlock\x18\x14 \x01(\x08\"\x84\x02\n\x0eRpcTransaction\x12\x0f\n\x07version\x18\x01 \x01(\r\x12.\n\x06inputs\x18\x02 \x03(\x0b\x32\x1e.protowire.RpcTransactionInput\x12\x30\n\x07outputs\x18\x03 \x03(\x0b\x32\x1f.protowire.RpcTransactionOutput\x12\x10\n\x08lockTime\x18\x04 \x01(\x04\x12\x14\n\x0csubnetworkId\x18\x05 \x01(\t\x12\x0b\n\x03gas\x18\x06 \x01(\x04\x12\x0f\n\x07payload\x18\x08 \x01(\t\x12\x39\n\x0bverboseData\x18\t \x01(\x0b\x32$.protowire.RpcTransactionVerboseData\"\xc6\x01\n\x13RpcTransactionInput\x12\x30\n\x10previousOutpoint\x18\x01 \x01(\x0b\x32\x16.protowire.RpcOutpoint\x12\x17\n\x0fsignatureScript\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x12\n\nsigOpCount\x18\x05 \x01(\r\x12>\n\x0bverboseData\x18\x04 \x01(\x0b\x32).protowire.RpcTransactionInputVerboseData\">\n\x12RpcScriptPublicKey\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x17\n\x0fscriptPublicKey\x18\x02 \x01(\t\"\x9f\x01\n\x14RpcTransactionOutput\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\x12\x36\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1d.protowire.RpcScriptPublicKey\x12?\n\x0bverboseData\x18\x03 \x01(\x0b\x32*.protowire.RpcTransactionOutputVerboseData\"3\n\x0bRpcOutpoint\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\"\x81\x01\n\x0cRpcUtxoEntry\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\x12\x36\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1d.protowire.RpcScriptPublicKey\x12\x15\n\rblockDaaScore\x18\x03 \x01(\x04\x12\x12\n\nisCoinbase\x18\x04 \x01(\x08\"t\n\x19RpcTransactionVerboseData\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04mass\x18\x04 \x01(\x04\x12\x11\n\tblockHash\x18\x0c \x01(\t\x12\x11\n\tblockTime\x18\x0e \x01(\x04\" \n\x1eRpcTransactionInputVerboseData\"^\n\x1fRpcTransactionOutputVerboseData\x12\x1b\n\x13scriptPublicKeyType\x18\x05 \x01(\t\x12\x1e\n\x16scriptPublicKeyAddress\x18\x06 \x01(\t\"!\n\x1fGetCurrentNetworkRequestMessage\"_\n GetCurrentNetworkResponseMessage\x12\x16\n\x0e\x63urrentNetwork\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"Z\n\x19SubmitBlockRequestMessage\x12\"\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x13.protowire.RpcBlock\x12\x19\n\x11\x61llowNonDAABlocks\x18\x03 \x01(\x08\"\xc7\x01\n\x1aSubmitBlockResponseMessage\x12H\n\x0crejectReason\x18\x01 \x01(\x0e\x32\x32.protowire.SubmitBlockResponseMessage.RejectReason\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\":\n\x0cRejectReason\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rBLOCK_INVALID\x10\x01\x12\r\n\tIS_IN_IBD\x10\x02\"G\n\x1eGetBlockTemplateRequestMessage\x12\x12\n\npayAddress\x18\x01 \x01(\t\x12\x11\n\textraData\x18\x02 \x01(\t\"|\n\x1fGetBlockTemplateResponseMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\x12\x10\n\x08isSynced\x18\x02 \x01(\x08\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\" \n\x1eNotifyBlockAddedRequestMessage\"F\n\x1fNotifyBlockAddedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"C\n\x1d\x42lockAddedNotificationMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\" \n\x1eGetPeerAddressesRequestMessage\"\xd2\x01\n\x1fGetPeerAddressesResponseMessage\x12\x41\n\taddresses\x18\x01 \x03(\x0b\x32..protowire.GetPeerAddressesKnownAddressMessage\x12G\n\x0f\x62\x61nnedAddresses\x18\x02 \x03(\x0b\x32..protowire.GetPeerAddressesKnownAddressMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"3\n#GetPeerAddressesKnownAddressMessage\x12\x0c\n\x04\x41\x64\x64r\x18\x01 \x01(\t\"\"\n GetSelectedTipHashRequestMessage\"a\n!GetSelectedTipHashResponseMessage\x12\x17\n\x0fselectedTipHash\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"g\n\x1dGetMempoolEntryRequestMessage\x12\x0c\n\x04txId\x18\x01 \x01(\t\x12\x19\n\x11includeOrphanPool\x18\x02 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x03 \x01(\x08\"m\n\x1eGetMempoolEntryResponseMessage\x12&\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x17.protowire.MempoolEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"[\n\x1fGetMempoolEntriesRequestMessage\x12\x19\n\x11includeOrphanPool\x18\x01 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x02 \x01(\x08\"q\n GetMempoolEntriesResponseMessage\x12(\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x17.protowire.MempoolEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"]\n\x0cMempoolEntry\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x04\x12.\n\x0btransaction\x18\x03 \x01(\x0b\x32\x19.protowire.RpcTransaction\x12\x10\n\x08isOrphan\x18\x04 \x01(\x08\"$\n\"GetConnectedPeerInfoRequestMessage\"\x81\x01\n#GetConnectedPeerInfoResponseMessage\x12\x35\n\x05infos\x18\x01 \x03(\x0b\x32&.protowire.GetConnectedPeerInfoMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\xdc\x01\n\x1bGetConnectedPeerInfoMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x18\n\x10lastPingDuration\x18\x03 \x01(\x03\x12\x12\n\nisOutbound\x18\x06 \x01(\x08\x12\x12\n\ntimeOffset\x18\x07 \x01(\x03\x12\x11\n\tuserAgent\x18\x08 \x01(\t\x12!\n\x19\x61\x64vertisedProtocolVersion\x18\t \x01(\r\x12\x15\n\rtimeConnected\x18\n \x01(\x03\x12\x11\n\tisIbdPeer\x18\x0b \x01(\x08\"=\n\x15\x41\x64\x64PeerRequestMessage\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0bisPermanent\x18\x02 \x01(\x08\"=\n\x16\x41\x64\x64PeerResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"f\n\x1fSubmitTransactionRequestMessage\x12.\n\x0btransaction\x18\x01 \x01(\x0b\x32\x19.protowire.RpcTransaction\x12\x13\n\x0b\x61llowOrphan\x18\x02 \x01(\x08\"^\n SubmitTransactionResponseMessage\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"^\n5NotifyVirtualSelectedParentChainChangedRequestMessage\x12%\n\x1dincludeAcceptedTransactionIds\x18\x01 \x01(\x08\"]\n6NotifyVirtualSelectedParentChainChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\xb9\x01\n4VirtualSelectedParentChainChangedNotificationMessage\x12\x1f\n\x17removedChainBlockHashes\x18\x01 \x03(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64\x43hainBlockHashes\x18\x03 \x03(\t\x12\x41\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\x0b\x32!.protowire.AcceptedTransactionIds\"C\n\x16GetBlockRequestMessage\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x1b\n\x13includeTransactions\x18\x03 \x01(\x08\"b\n\x17GetBlockResponseMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"3\n\x1bGetSubnetworkRequestMessage\x12\x14\n\x0csubnetworkId\x18\x01 \x01(\t\"U\n\x1cGetSubnetworkResponseMessage\x12\x10\n\x08gasLimit\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"p\n4GetVirtualSelectedParentChainFromBlockRequestMessage\x12\x11\n\tstartHash\x18\x01 \x01(\t\x12%\n\x1dincludeAcceptedTransactionIds\x18\x02 \x01(\x08\"T\n\x16\x41\x63\x63\x65ptedTransactionIds\x12\x1a\n\x12\x61\x63\x63\x65ptingBlockHash\x18\x01 \x01(\t\x12\x1e\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\t\"\xdf\x01\n5GetVirtualSelectedParentChainFromBlockResponseMessage\x12\x1f\n\x17removedChainBlockHashes\x18\x01 \x03(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64\x43hainBlockHashes\x18\x03 \x03(\t\x12\x41\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\x0b\x32!.protowire.AcceptedTransactionIds\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"^\n\x17GetBlocksRequestMessage\x12\x0f\n\x07lowHash\x18\x01 \x01(\t\x12\x15\n\rincludeBlocks\x18\x02 \x01(\x08\x12\x1b\n\x13includeTransactions\x18\x03 \x01(\x08\"y\n\x18GetBlocksResponseMessage\x12\x13\n\x0b\x62lockHashes\x18\x04 \x03(\t\x12#\n\x06\x62locks\x18\x03 \x03(\x0b\x32\x13.protowire.RpcBlock\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetBlockCountRequestMessage\"l\n\x1cGetBlockCountResponseMessage\x12\x12\n\nblockCount\x18\x01 \x01(\x04\x12\x13\n\x0bheaderCount\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1f\n\x1dGetBlockDagInfoRequestMessage\"\x92\x02\n\x1eGetBlockDagInfoResponseMessage\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nblockCount\x18\x02 \x01(\x04\x12\x13\n\x0bheaderCount\x18\x03 \x01(\x04\x12\x11\n\ttipHashes\x18\x04 \x03(\t\x12\x12\n\ndifficulty\x18\x05 \x01(\x01\x12\x16\n\x0epastMedianTime\x18\x06 \x01(\x03\x12\x1b\n\x13virtualParentHashes\x18\x07 \x03(\t\x12\x18\n\x10pruningPointHash\x18\x08 \x01(\t\x12\x17\n\x0fvirtualDaaScore\x18\t \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"B\n%ResolveFinalityConflictRequestMessage\x12\x19\n\x11\x66inalityBlockHash\x18\x01 \x01(\t\"M\n&ResolveFinalityConflictResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\'\n%NotifyFinalityConflictsRequestMessage\"M\n&NotifyFinalityConflictsResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"A\n#FinalityConflictNotificationMessage\x12\x1a\n\x12violatingBlockHash\x18\x01 \x01(\t\"H\n+FinalityConflictResolvedNotificationMessage\x12\x19\n\x11\x66inalityBlockHash\x18\x01 \x01(\t\"\x18\n\x16ShutDownRequestMessage\">\n\x17ShutDownResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"Q\n\x18GetHeadersRequestMessage\x12\x11\n\tstartHash\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x13\n\x0bisAscending\x18\x03 \x01(\x08\"Q\n\x19GetHeadersResponseMessage\x12\x0f\n\x07headers\x18\x01 \x03(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"5\n NotifyUtxosChangedRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"H\n!NotifyUtxosChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x85\x01\n\x1fUtxosChangedNotificationMessage\x12/\n\x05\x61\x64\x64\x65\x64\x18\x01 \x03(\x0b\x32 .protowire.UtxosByAddressesEntry\x12\x31\n\x07removed\x18\x02 \x03(\x0b\x32 .protowire.UtxosByAddressesEntry\"~\n\x15UtxosByAddressesEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12(\n\x08outpoint\x18\x02 \x01(\x0b\x32\x16.protowire.RpcOutpoint\x12*\n\tutxoEntry\x18\x03 \x01(\x0b\x32\x17.protowire.RpcUtxoEntry\"<\n\'StopNotifyingUtxosChangedRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"O\n(StopNotifyingUtxosChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"6\n!GetUtxosByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"|\n\"GetUtxosByAddressesResponseMessage\x12\x31\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .protowire.UtxosByAddressesEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"4\n!GetBalanceByAddressRequestMessage\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"Z\n\"GetBalanceByAddressResponseMessage\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"9\n$GetBalancesByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"_\n\x16\x42\x61lancesByAddressEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x80\x01\n%GetBalancesByAddressesResponseMessage\x12\x32\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.protowire.BalancesByAddressEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"1\n/GetVirtualSelectedParentBlueScoreRequestMessage\"j\n0GetVirtualSelectedParentBlueScoreResponseMessage\x12\x11\n\tblueScore\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\";\n9NotifyVirtualSelectedParentBlueScoreChangedRequestMessage\"a\n:NotifyVirtualSelectedParentBlueScoreChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"b\n8VirtualSelectedParentBlueScoreChangedNotificationMessage\x12&\n\x1evirtualSelectedParentBlueScore\x18\x01 \x01(\x04\",\n*NotifyVirtualDaaScoreChangedRequestMessage\"R\n+NotifyVirtualDaaScoreChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"D\n)VirtualDaaScoreChangedNotificationMessage\x12\x17\n\x0fvirtualDaaScore\x18\x01 \x01(\x04\"1\n/NotifyPruningPointUTXOSetOverrideRequestMessage\"W\n0NotifyPruningPointUTXOSetOverrideResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"0\n.PruningPointUTXOSetOverrideNotificationMessage\"8\n6StopNotifyingPruningPointUTXOSetOverrideRequestMessage\"^\n7StopNotifyingPruningPointUTXOSetOverrideResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1f\n\x11\x42\x61nRequestMessage\x12\n\n\x02ip\x18\x01 \x01(\t\"9\n\x12\x42\x61nResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"!\n\x13UnbanRequestMessage\x12\n\n\x02ip\x18\x01 \x01(\t\";\n\x14UnbanResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x17\n\x15GetInfoRequestMessage\"\xa1\x01\n\x16GetInfoResponseMessage\x12\r\n\x05p2pId\x18\x01 \x01(\t\x12\x13\n\x0bmempoolSize\x18\x02 \x01(\x04\x12\x15\n\rserverVersion\x18\x03 \x01(\t\x12\x15\n\risUtxoIndexed\x18\x04 \x01(\x08\x12\x10\n\x08isSynced\x18\x05 \x01(\x08\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"U\n,EstimateNetworkHashesPerSecondRequestMessage\x12\x12\n\nwindowSize\x18\x01 \x01(\r\x12\x11\n\tstartHash\x18\x02 \x01(\t\"t\n-EstimateNetworkHashesPerSecondResponseMessage\x12\x1e\n\x16networkHashesPerSecond\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"&\n$NotifyNewBlockTemplateRequestMessage\"L\n%NotifyNewBlockTemplateResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"%\n#NewBlockTemplateNotificationMessage\"~\n\x15MempoolEntryByAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12(\n\x07sending\x18\x02 \x03(\x0b\x32\x17.protowire.MempoolEntry\x12*\n\treceiving\x18\x03 \x03(\x0b\x32\x17.protowire.MempoolEntry\"y\n*GetMempoolEntriesByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x19\n\x11includeOrphanPool\x18\x02 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x03 \x01(\x08\"\x85\x01\n+GetMempoolEntriesByAddressesResponseMessage\x12\x31\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .protowire.MempoolEntryByAddress\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetCoinSupplyRequestMessage\"o\n\x1cGetCoinSupplyResponseMessage\x12\x10\n\x08maxSompi\x18\x01 \x01(\x04\x12\x18\n\x10\x63irculatingSompi\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCErrorB&Z$github.com/kaspanet/kaspad/protowireb\x06proto3')



_RPCERROR = DESCRIPTOR.message_types_by_name['RPCError']
_RPCBLOCK = DESCRIPTOR.message_types_by_name['RpcBlock']
_RPCBLOCKHEADER = DESCRIPTOR.message_types_by_name['RpcBlockHeader']
_RPCBLOCKLEVELPARENTS = DESCRIPTOR.message_types_by_name['RpcBlockLevelParents']
_RPCBLOCKVERBOSEDATA = DESCRIPTOR.message_types_by_name['RpcBlockVerboseData']
_RPCTRANSACTION = DESCRIPTOR.message_types_by_name['RpcTransaction']
_RPCTRANSACTIONINPUT = DESCRIPTOR.message_types_by_name['RpcTransactionInput']
_RPCSCRIPTPUBLICKEY = DESCRIPTOR.message_types_by_name['RpcScriptPublicKey']
_RPCTRANSACTIONOUTPUT = DESCRIPTOR.message_types_by_name['RpcTransactionOutput']
_RPCOUTPOINT = DESCRIPTOR.message_types_by_name['RpcOutpoint']
_RPCUTXOENTRY = DESCRIPTOR.message_types_by_name['RpcUtxoEntry']
_RPCTRANSACTIONVERBOSEDATA = DESCRIPTOR.message_types_by_name['RpcTransactionVerboseData']
_RPCTRANSACTIONINPUTVERBOSEDATA = DESCRIPTOR.message_types_by_name['RpcTransactionInputVerboseData']
_RPCTRANSACTIONOUTPUTVERBOSEDATA = DESCRIPTOR.message_types_by_name['RpcTransactionOutputVerboseData']
_GETCURRENTNETWORKREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetCurrentNetworkRequestMessage']
_GETCURRENTNETWORKRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetCurrentNetworkResponseMessage']
_SUBMITBLOCKREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['SubmitBlockRequestMessage']
_SUBMITBLOCKRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['SubmitBlockResponseMessage']
_GETBLOCKTEMPLATEREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockTemplateRequestMessage']
_GETBLOCKTEMPLATERESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockTemplateResponseMessage']
_NOTIFYBLOCKADDEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyBlockAddedRequestMessage']
_NOTIFYBLOCKADDEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyBlockAddedResponseMessage']
_BLOCKADDEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['BlockAddedNotificationMessage']
_GETPEERADDRESSESREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetPeerAddressesRequestMessage']
_GETPEERADDRESSESRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetPeerAddressesResponseMessage']
_GETPEERADDRESSESKNOWNADDRESSMESSAGE = DESCRIPTOR.message_types_by_name['GetPeerAddressesKnownAddressMessage']
_GETSELECTEDTIPHASHREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetSelectedTipHashRequestMessage']
_GETSELECTEDTIPHASHRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetSelectedTipHashResponseMessage']
_GETMEMPOOLENTRYREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntryRequestMessage']
_GETMEMPOOLENTRYRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntryResponseMessage']
_GETMEMPOOLENTRIESREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntriesRequestMessage']
_GETMEMPOOLENTRIESRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntriesResponseMessage']
_MEMPOOLENTRY = DESCRIPTOR.message_types_by_name['MempoolEntry']
_GETCONNECTEDPEERINFOREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetConnectedPeerInfoRequestMessage']
_GETCONNECTEDPEERINFORESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetConnectedPeerInfoResponseMessage']
_GETCONNECTEDPEERINFOMESSAGE = DESCRIPTOR.message_types_by_name['GetConnectedPeerInfoMessage']
_ADDPEERREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['AddPeerRequestMessage']
_ADDPEERRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['AddPeerResponseMessage']
_SUBMITTRANSACTIONREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['SubmitTransactionRequestMessage']
_SUBMITTRANSACTIONRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['SubmitTransactionResponseMessage']
_NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualSelectedParentChainChangedRequestMessage']
_NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualSelectedParentChainChangedResponseMessage']
_VIRTUALSELECTEDPARENTCHAINCHANGEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['VirtualSelectedParentChainChangedNotificationMessage']
_GETBLOCKREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockRequestMessage']
_GETBLOCKRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockResponseMessage']
_GETSUBNETWORKREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetSubnetworkRequestMessage']
_GETSUBNETWORKRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetSubnetworkResponseMessage']
_GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetVirtualSelectedParentChainFromBlockRequestMessage']
_ACCEPTEDTRANSACTIONIDS = DESCRIPTOR.message_types_by_name['AcceptedTransactionIds']
_GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetVirtualSelectedParentChainFromBlockResponseMessage']
_GETBLOCKSREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBlocksRequestMessage']
_GETBLOCKSRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBlocksResponseMessage']
_GETBLOCKCOUNTREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockCountRequestMessage']
_GETBLOCKCOUNTRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockCountResponseMessage']
_GETBLOCKDAGINFOREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockDagInfoRequestMessage']
_GETBLOCKDAGINFORESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBlockDagInfoResponseMessage']
_RESOLVEFINALITYCONFLICTREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['ResolveFinalityConflictRequestMessage']
_RESOLVEFINALITYCONFLICTRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['ResolveFinalityConflictResponseMessage']
_NOTIFYFINALITYCONFLICTSREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyFinalityConflictsRequestMessage']
_NOTIFYFINALITYCONFLICTSRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyFinalityConflictsResponseMessage']
_FINALITYCONFLICTNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['FinalityConflictNotificationMessage']
_FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['FinalityConflictResolvedNotificationMessage']
_SHUTDOWNREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['ShutDownRequestMessage']
_SHUTDOWNRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['ShutDownResponseMessage']
_GETHEADERSREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetHeadersRequestMessage']
_GETHEADERSRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetHeadersResponseMessage']
_NOTIFYUTXOSCHANGEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyUtxosChangedRequestMessage']
_NOTIFYUTXOSCHANGEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyUtxosChangedResponseMessage']
_UTXOSCHANGEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['UtxosChangedNotificationMessage']
_UTXOSBYADDRESSESENTRY = DESCRIPTOR.message_types_by_name['UtxosByAddressesEntry']
_STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['StopNotifyingUtxosChangedRequestMessage']
_STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['StopNotifyingUtxosChangedResponseMessage']
_GETUTXOSBYADDRESSESREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetUtxosByAddressesRequestMessage']
_GETUTXOSBYADDRESSESRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetUtxosByAddressesResponseMessage']
_GETBALANCEBYADDRESSREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBalanceByAddressRequestMessage']
_GETBALANCEBYADDRESSRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBalanceByAddressResponseMessage']
_GETBALANCESBYADDRESSESREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetBalancesByAddressesRequestMessage']
_BALANCESBYADDRESSENTRY = DESCRIPTOR.message_types_by_name['BalancesByAddressEntry']
_GETBALANCESBYADDRESSESRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetBalancesByAddressesResponseMessage']
_GETVIRTUALSELECTEDPARENTBLUESCOREREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetVirtualSelectedParentBlueScoreRequestMessage']
_GETVIRTUALSELECTEDPARENTBLUESCORERESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetVirtualSelectedParentBlueScoreResponseMessage']
_NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualSelectedParentBlueScoreChangedRequestMessage']
_NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualSelectedParentBlueScoreChangedResponseMessage']
_VIRTUALSELECTEDPARENTBLUESCORECHANGEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['VirtualSelectedParentBlueScoreChangedNotificationMessage']
_NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualDaaScoreChangedRequestMessage']
_NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyVirtualDaaScoreChangedResponseMessage']
_VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['VirtualDaaScoreChangedNotificationMessage']
_NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyPruningPointUTXOSetOverrideRequestMessage']
_NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyPruningPointUTXOSetOverrideResponseMessage']
_PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['PruningPointUTXOSetOverrideNotificationMessage']
_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['StopNotifyingPruningPointUTXOSetOverrideRequestMessage']
_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['StopNotifyingPruningPointUTXOSetOverrideResponseMessage']
_BANREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['BanRequestMessage']
_BANRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['BanResponseMessage']
_UNBANREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['UnbanRequestMessage']
_UNBANRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['UnbanResponseMessage']
_GETINFOREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetInfoRequestMessage']
_GETINFORESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetInfoResponseMessage']
_ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['EstimateNetworkHashesPerSecondRequestMessage']
_ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['EstimateNetworkHashesPerSecondResponseMessage']
_NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['NotifyNewBlockTemplateRequestMessage']
_NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['NotifyNewBlockTemplateResponseMessage']
_NEWBLOCKTEMPLATENOTIFICATIONMESSAGE = DESCRIPTOR.message_types_by_name['NewBlockTemplateNotificationMessage']
_MEMPOOLENTRYBYADDRESS = DESCRIPTOR.message_types_by_name['MempoolEntryByAddress']
_GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntriesByAddressesRequestMessage']
_GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetMempoolEntriesByAddressesResponseMessage']
_GETCOINSUPPLYREQUESTMESSAGE = DESCRIPTOR.message_types_by_name['GetCoinSupplyRequestMessage']
_GETCOINSUPPLYRESPONSEMESSAGE = DESCRIPTOR.message_types_by_name['GetCoinSupplyResponseMessage']
_SUBMITBLOCKRESPONSEMESSAGE_REJECTREASON = _SUBMITBLOCKRESPONSEMESSAGE.enum_types_by_name['RejectReason']
RPCError = _reflection.GeneratedProtocolMessageType('RPCError', (_message.Message,), {
  'DESCRIPTOR' : _RPCERROR,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RPCError)
  })
_sym_db.RegisterMessage(RPCError)

RpcBlock = _reflection.GeneratedProtocolMessageType('RpcBlock', (_message.Message,), {
  'DESCRIPTOR' : _RPCBLOCK,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcBlock)
  })
_sym_db.RegisterMessage(RpcBlock)

RpcBlockHeader = _reflection.GeneratedProtocolMessageType('RpcBlockHeader', (_message.Message,), {
  'DESCRIPTOR' : _RPCBLOCKHEADER,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcBlockHeader)
  })
_sym_db.RegisterMessage(RpcBlockHeader)

RpcBlockLevelParents = _reflection.GeneratedProtocolMessageType('RpcBlockLevelParents', (_message.Message,), {
  'DESCRIPTOR' : _RPCBLOCKLEVELPARENTS,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcBlockLevelParents)
  })
_sym_db.RegisterMessage(RpcBlockLevelParents)

RpcBlockVerboseData = _reflection.GeneratedProtocolMessageType('RpcBlockVerboseData', (_message.Message,), {
  'DESCRIPTOR' : _RPCBLOCKVERBOSEDATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcBlockVerboseData)
  })
_sym_db.RegisterMessage(RpcBlockVerboseData)

RpcTransaction = _reflection.GeneratedProtocolMessageType('RpcTransaction', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTION,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransaction)
  })
_sym_db.RegisterMessage(RpcTransaction)

RpcTransactionInput = _reflection.GeneratedProtocolMessageType('RpcTransactionInput', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTIONINPUT,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransactionInput)
  })
_sym_db.RegisterMessage(RpcTransactionInput)

RpcScriptPublicKey = _reflection.GeneratedProtocolMessageType('RpcScriptPublicKey', (_message.Message,), {
  'DESCRIPTOR' : _RPCSCRIPTPUBLICKEY,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcScriptPublicKey)
  })
_sym_db.RegisterMessage(RpcScriptPublicKey)

RpcTransactionOutput = _reflection.GeneratedProtocolMessageType('RpcTransactionOutput', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTIONOUTPUT,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransactionOutput)
  })
_sym_db.RegisterMessage(RpcTransactionOutput)

RpcOutpoint = _reflection.GeneratedProtocolMessageType('RpcOutpoint', (_message.Message,), {
  'DESCRIPTOR' : _RPCOUTPOINT,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcOutpoint)
  })
_sym_db.RegisterMessage(RpcOutpoint)

RpcUtxoEntry = _reflection.GeneratedProtocolMessageType('RpcUtxoEntry', (_message.Message,), {
  'DESCRIPTOR' : _RPCUTXOENTRY,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcUtxoEntry)
  })
_sym_db.RegisterMessage(RpcUtxoEntry)

RpcTransactionVerboseData = _reflection.GeneratedProtocolMessageType('RpcTransactionVerboseData', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTIONVERBOSEDATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransactionVerboseData)
  })
_sym_db.RegisterMessage(RpcTransactionVerboseData)

RpcTransactionInputVerboseData = _reflection.GeneratedProtocolMessageType('RpcTransactionInputVerboseData', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTIONINPUTVERBOSEDATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransactionInputVerboseData)
  })
_sym_db.RegisterMessage(RpcTransactionInputVerboseData)

RpcTransactionOutputVerboseData = _reflection.GeneratedProtocolMessageType('RpcTransactionOutputVerboseData', (_message.Message,), {
  'DESCRIPTOR' : _RPCTRANSACTIONOUTPUTVERBOSEDATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RpcTransactionOutputVerboseData)
  })
_sym_db.RegisterMessage(RpcTransactionOutputVerboseData)

GetCurrentNetworkRequestMessage = _reflection.GeneratedProtocolMessageType('GetCurrentNetworkRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTNETWORKREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetCurrentNetworkRequestMessage)
  })
_sym_db.RegisterMessage(GetCurrentNetworkRequestMessage)

GetCurrentNetworkResponseMessage = _reflection.GeneratedProtocolMessageType('GetCurrentNetworkResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTNETWORKRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetCurrentNetworkResponseMessage)
  })
_sym_db.RegisterMessage(GetCurrentNetworkResponseMessage)

SubmitBlockRequestMessage = _reflection.GeneratedProtocolMessageType('SubmitBlockRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITBLOCKREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.SubmitBlockRequestMessage)
  })
_sym_db.RegisterMessage(SubmitBlockRequestMessage)

SubmitBlockResponseMessage = _reflection.GeneratedProtocolMessageType('SubmitBlockResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITBLOCKRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.SubmitBlockResponseMessage)
  })
_sym_db.RegisterMessage(SubmitBlockResponseMessage)

GetBlockTemplateRequestMessage = _reflection.GeneratedProtocolMessageType('GetBlockTemplateRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKTEMPLATEREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockTemplateRequestMessage)
  })
_sym_db.RegisterMessage(GetBlockTemplateRequestMessage)

GetBlockTemplateResponseMessage = _reflection.GeneratedProtocolMessageType('GetBlockTemplateResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKTEMPLATERESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockTemplateResponseMessage)
  })
_sym_db.RegisterMessage(GetBlockTemplateResponseMessage)

NotifyBlockAddedRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyBlockAddedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYBLOCKADDEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyBlockAddedRequestMessage)
  })
_sym_db.RegisterMessage(NotifyBlockAddedRequestMessage)

NotifyBlockAddedResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyBlockAddedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYBLOCKADDEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyBlockAddedResponseMessage)
  })
_sym_db.RegisterMessage(NotifyBlockAddedResponseMessage)

BlockAddedNotificationMessage = _reflection.GeneratedProtocolMessageType('BlockAddedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKADDEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockAddedNotificationMessage)
  })
_sym_db.RegisterMessage(BlockAddedNotificationMessage)

GetPeerAddressesRequestMessage = _reflection.GeneratedProtocolMessageType('GetPeerAddressesRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERADDRESSESREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetPeerAddressesRequestMessage)
  })
_sym_db.RegisterMessage(GetPeerAddressesRequestMessage)

GetPeerAddressesResponseMessage = _reflection.GeneratedProtocolMessageType('GetPeerAddressesResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERADDRESSESRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetPeerAddressesResponseMessage)
  })
_sym_db.RegisterMessage(GetPeerAddressesResponseMessage)

GetPeerAddressesKnownAddressMessage = _reflection.GeneratedProtocolMessageType('GetPeerAddressesKnownAddressMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERADDRESSESKNOWNADDRESSMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetPeerAddressesKnownAddressMessage)
  })
_sym_db.RegisterMessage(GetPeerAddressesKnownAddressMessage)

GetSelectedTipHashRequestMessage = _reflection.GeneratedProtocolMessageType('GetSelectedTipHashRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETSELECTEDTIPHASHREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetSelectedTipHashRequestMessage)
  })
_sym_db.RegisterMessage(GetSelectedTipHashRequestMessage)

GetSelectedTipHashResponseMessage = _reflection.GeneratedProtocolMessageType('GetSelectedTipHashResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETSELECTEDTIPHASHRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetSelectedTipHashResponseMessage)
  })
_sym_db.RegisterMessage(GetSelectedTipHashResponseMessage)

GetMempoolEntryRequestMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntryRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRYREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntryRequestMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntryRequestMessage)

GetMempoolEntryResponseMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntryResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRYRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntryResponseMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntryResponseMessage)

GetMempoolEntriesRequestMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntriesRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRIESREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntriesRequestMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntriesRequestMessage)

GetMempoolEntriesResponseMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntriesResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRIESRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntriesResponseMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntriesResponseMessage)

MempoolEntry = _reflection.GeneratedProtocolMessageType('MempoolEntry', (_message.Message,), {
  'DESCRIPTOR' : _MEMPOOLENTRY,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.MempoolEntry)
  })
_sym_db.RegisterMessage(MempoolEntry)

GetConnectedPeerInfoRequestMessage = _reflection.GeneratedProtocolMessageType('GetConnectedPeerInfoRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTEDPEERINFOREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetConnectedPeerInfoRequestMessage)
  })
_sym_db.RegisterMessage(GetConnectedPeerInfoRequestMessage)

GetConnectedPeerInfoResponseMessage = _reflection.GeneratedProtocolMessageType('GetConnectedPeerInfoResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTEDPEERINFORESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetConnectedPeerInfoResponseMessage)
  })
_sym_db.RegisterMessage(GetConnectedPeerInfoResponseMessage)

GetConnectedPeerInfoMessage = _reflection.GeneratedProtocolMessageType('GetConnectedPeerInfoMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTEDPEERINFOMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetConnectedPeerInfoMessage)
  })
_sym_db.RegisterMessage(GetConnectedPeerInfoMessage)

AddPeerRequestMessage = _reflection.GeneratedProtocolMessageType('AddPeerRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.AddPeerRequestMessage)
  })
_sym_db.RegisterMessage(AddPeerRequestMessage)

AddPeerResponseMessage = _reflection.GeneratedProtocolMessageType('AddPeerResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.AddPeerResponseMessage)
  })
_sym_db.RegisterMessage(AddPeerResponseMessage)

SubmitTransactionRequestMessage = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.SubmitTransactionRequestMessage)
  })
_sym_db.RegisterMessage(SubmitTransactionRequestMessage)

SubmitTransactionResponseMessage = _reflection.GeneratedProtocolMessageType('SubmitTransactionResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.SubmitTransactionResponseMessage)
  })
_sym_db.RegisterMessage(SubmitTransactionResponseMessage)

NotifyVirtualSelectedParentChainChangedRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualSelectedParentChainChangedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualSelectedParentChainChangedRequestMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualSelectedParentChainChangedRequestMessage)

NotifyVirtualSelectedParentChainChangedResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualSelectedParentChainChangedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualSelectedParentChainChangedResponseMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualSelectedParentChainChangedResponseMessage)

VirtualSelectedParentChainChangedNotificationMessage = _reflection.GeneratedProtocolMessageType('VirtualSelectedParentChainChangedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALSELECTEDPARENTCHAINCHANGEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.VirtualSelectedParentChainChangedNotificationMessage)
  })
_sym_db.RegisterMessage(VirtualSelectedParentChainChangedNotificationMessage)

GetBlockRequestMessage = _reflection.GeneratedProtocolMessageType('GetBlockRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockRequestMessage)
  })
_sym_db.RegisterMessage(GetBlockRequestMessage)

GetBlockResponseMessage = _reflection.GeneratedProtocolMessageType('GetBlockResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockResponseMessage)
  })
_sym_db.RegisterMessage(GetBlockResponseMessage)

GetSubnetworkRequestMessage = _reflection.GeneratedProtocolMessageType('GetSubnetworkRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBNETWORKREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetSubnetworkRequestMessage)
  })
_sym_db.RegisterMessage(GetSubnetworkRequestMessage)

GetSubnetworkResponseMessage = _reflection.GeneratedProtocolMessageType('GetSubnetworkResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBNETWORKRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetSubnetworkResponseMessage)
  })
_sym_db.RegisterMessage(GetSubnetworkResponseMessage)

GetVirtualSelectedParentChainFromBlockRequestMessage = _reflection.GeneratedProtocolMessageType('GetVirtualSelectedParentChainFromBlockRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetVirtualSelectedParentChainFromBlockRequestMessage)
  })
_sym_db.RegisterMessage(GetVirtualSelectedParentChainFromBlockRequestMessage)

AcceptedTransactionIds = _reflection.GeneratedProtocolMessageType('AcceptedTransactionIds', (_message.Message,), {
  'DESCRIPTOR' : _ACCEPTEDTRANSACTIONIDS,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.AcceptedTransactionIds)
  })
_sym_db.RegisterMessage(AcceptedTransactionIds)

GetVirtualSelectedParentChainFromBlockResponseMessage = _reflection.GeneratedProtocolMessageType('GetVirtualSelectedParentChainFromBlockResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetVirtualSelectedParentChainFromBlockResponseMessage)
  })
_sym_db.RegisterMessage(GetVirtualSelectedParentChainFromBlockResponseMessage)

GetBlocksRequestMessage = _reflection.GeneratedProtocolMessageType('GetBlocksRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlocksRequestMessage)
  })
_sym_db.RegisterMessage(GetBlocksRequestMessage)

GetBlocksResponseMessage = _reflection.GeneratedProtocolMessageType('GetBlocksResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlocksResponseMessage)
  })
_sym_db.RegisterMessage(GetBlocksResponseMessage)

GetBlockCountRequestMessage = _reflection.GeneratedProtocolMessageType('GetBlockCountRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKCOUNTREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockCountRequestMessage)
  })
_sym_db.RegisterMessage(GetBlockCountRequestMessage)

GetBlockCountResponseMessage = _reflection.GeneratedProtocolMessageType('GetBlockCountResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKCOUNTRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockCountResponseMessage)
  })
_sym_db.RegisterMessage(GetBlockCountResponseMessage)

GetBlockDagInfoRequestMessage = _reflection.GeneratedProtocolMessageType('GetBlockDagInfoRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKDAGINFOREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockDagInfoRequestMessage)
  })
_sym_db.RegisterMessage(GetBlockDagInfoRequestMessage)

GetBlockDagInfoResponseMessage = _reflection.GeneratedProtocolMessageType('GetBlockDagInfoResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKDAGINFORESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBlockDagInfoResponseMessage)
  })
_sym_db.RegisterMessage(GetBlockDagInfoResponseMessage)

ResolveFinalityConflictRequestMessage = _reflection.GeneratedProtocolMessageType('ResolveFinalityConflictRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEFINALITYCONFLICTREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ResolveFinalityConflictRequestMessage)
  })
_sym_db.RegisterMessage(ResolveFinalityConflictRequestMessage)

ResolveFinalityConflictResponseMessage = _reflection.GeneratedProtocolMessageType('ResolveFinalityConflictResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEFINALITYCONFLICTRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ResolveFinalityConflictResponseMessage)
  })
_sym_db.RegisterMessage(ResolveFinalityConflictResponseMessage)

NotifyFinalityConflictsRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyFinalityConflictsRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYFINALITYCONFLICTSREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyFinalityConflictsRequestMessage)
  })
_sym_db.RegisterMessage(NotifyFinalityConflictsRequestMessage)

NotifyFinalityConflictsResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyFinalityConflictsResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYFINALITYCONFLICTSRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyFinalityConflictsResponseMessage)
  })
_sym_db.RegisterMessage(NotifyFinalityConflictsResponseMessage)

FinalityConflictNotificationMessage = _reflection.GeneratedProtocolMessageType('FinalityConflictNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _FINALITYCONFLICTNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.FinalityConflictNotificationMessage)
  })
_sym_db.RegisterMessage(FinalityConflictNotificationMessage)

FinalityConflictResolvedNotificationMessage = _reflection.GeneratedProtocolMessageType('FinalityConflictResolvedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.FinalityConflictResolvedNotificationMessage)
  })
_sym_db.RegisterMessage(FinalityConflictResolvedNotificationMessage)

ShutDownRequestMessage = _reflection.GeneratedProtocolMessageType('ShutDownRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ShutDownRequestMessage)
  })
_sym_db.RegisterMessage(ShutDownRequestMessage)

ShutDownResponseMessage = _reflection.GeneratedProtocolMessageType('ShutDownResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ShutDownResponseMessage)
  })
_sym_db.RegisterMessage(ShutDownResponseMessage)

GetHeadersRequestMessage = _reflection.GeneratedProtocolMessageType('GetHeadersRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETHEADERSREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetHeadersRequestMessage)
  })
_sym_db.RegisterMessage(GetHeadersRequestMessage)

GetHeadersResponseMessage = _reflection.GeneratedProtocolMessageType('GetHeadersResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETHEADERSRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetHeadersResponseMessage)
  })
_sym_db.RegisterMessage(GetHeadersResponseMessage)

NotifyUtxosChangedRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyUtxosChangedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUTXOSCHANGEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyUtxosChangedRequestMessage)
  })
_sym_db.RegisterMessage(NotifyUtxosChangedRequestMessage)

NotifyUtxosChangedResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyUtxosChangedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUTXOSCHANGEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyUtxosChangedResponseMessage)
  })
_sym_db.RegisterMessage(NotifyUtxosChangedResponseMessage)

UtxosChangedNotificationMessage = _reflection.GeneratedProtocolMessageType('UtxosChangedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _UTXOSCHANGEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UtxosChangedNotificationMessage)
  })
_sym_db.RegisterMessage(UtxosChangedNotificationMessage)

UtxosByAddressesEntry = _reflection.GeneratedProtocolMessageType('UtxosByAddressesEntry', (_message.Message,), {
  'DESCRIPTOR' : _UTXOSBYADDRESSESENTRY,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UtxosByAddressesEntry)
  })
_sym_db.RegisterMessage(UtxosByAddressesEntry)

StopNotifyingUtxosChangedRequestMessage = _reflection.GeneratedProtocolMessageType('StopNotifyingUtxosChangedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.StopNotifyingUtxosChangedRequestMessage)
  })
_sym_db.RegisterMessage(StopNotifyingUtxosChangedRequestMessage)

StopNotifyingUtxosChangedResponseMessage = _reflection.GeneratedProtocolMessageType('StopNotifyingUtxosChangedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.StopNotifyingUtxosChangedResponseMessage)
  })
_sym_db.RegisterMessage(StopNotifyingUtxosChangedResponseMessage)

GetUtxosByAddressesRequestMessage = _reflection.GeneratedProtocolMessageType('GetUtxosByAddressesRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETUTXOSBYADDRESSESREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetUtxosByAddressesRequestMessage)
  })
_sym_db.RegisterMessage(GetUtxosByAddressesRequestMessage)

GetUtxosByAddressesResponseMessage = _reflection.GeneratedProtocolMessageType('GetUtxosByAddressesResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETUTXOSBYADDRESSESRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetUtxosByAddressesResponseMessage)
  })
_sym_db.RegisterMessage(GetUtxosByAddressesResponseMessage)

GetBalanceByAddressRequestMessage = _reflection.GeneratedProtocolMessageType('GetBalanceByAddressRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEBYADDRESSREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBalanceByAddressRequestMessage)
  })
_sym_db.RegisterMessage(GetBalanceByAddressRequestMessage)

GetBalanceByAddressResponseMessage = _reflection.GeneratedProtocolMessageType('GetBalanceByAddressResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEBYADDRESSRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBalanceByAddressResponseMessage)
  })
_sym_db.RegisterMessage(GetBalanceByAddressResponseMessage)

GetBalancesByAddressesRequestMessage = _reflection.GeneratedProtocolMessageType('GetBalancesByAddressesRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCESBYADDRESSESREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBalancesByAddressesRequestMessage)
  })
_sym_db.RegisterMessage(GetBalancesByAddressesRequestMessage)

BalancesByAddressEntry = _reflection.GeneratedProtocolMessageType('BalancesByAddressEntry', (_message.Message,), {
  'DESCRIPTOR' : _BALANCESBYADDRESSENTRY,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BalancesByAddressEntry)
  })
_sym_db.RegisterMessage(BalancesByAddressEntry)

GetBalancesByAddressesResponseMessage = _reflection.GeneratedProtocolMessageType('GetBalancesByAddressesResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCESBYADDRESSESRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetBalancesByAddressesResponseMessage)
  })
_sym_db.RegisterMessage(GetBalancesByAddressesResponseMessage)

GetVirtualSelectedParentBlueScoreRequestMessage = _reflection.GeneratedProtocolMessageType('GetVirtualSelectedParentBlueScoreRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALSELECTEDPARENTBLUESCOREREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetVirtualSelectedParentBlueScoreRequestMessage)
  })
_sym_db.RegisterMessage(GetVirtualSelectedParentBlueScoreRequestMessage)

GetVirtualSelectedParentBlueScoreResponseMessage = _reflection.GeneratedProtocolMessageType('GetVirtualSelectedParentBlueScoreResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALSELECTEDPARENTBLUESCORERESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetVirtualSelectedParentBlueScoreResponseMessage)
  })
_sym_db.RegisterMessage(GetVirtualSelectedParentBlueScoreResponseMessage)

NotifyVirtualSelectedParentBlueScoreChangedRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualSelectedParentBlueScoreChangedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualSelectedParentBlueScoreChangedRequestMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualSelectedParentBlueScoreChangedRequestMessage)

NotifyVirtualSelectedParentBlueScoreChangedResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualSelectedParentBlueScoreChangedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualSelectedParentBlueScoreChangedResponseMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualSelectedParentBlueScoreChangedResponseMessage)

VirtualSelectedParentBlueScoreChangedNotificationMessage = _reflection.GeneratedProtocolMessageType('VirtualSelectedParentBlueScoreChangedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALSELECTEDPARENTBLUESCORECHANGEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.VirtualSelectedParentBlueScoreChangedNotificationMessage)
  })
_sym_db.RegisterMessage(VirtualSelectedParentBlueScoreChangedNotificationMessage)

NotifyVirtualDaaScoreChangedRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualDaaScoreChangedRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualDaaScoreChangedRequestMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualDaaScoreChangedRequestMessage)

NotifyVirtualDaaScoreChangedResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyVirtualDaaScoreChangedResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyVirtualDaaScoreChangedResponseMessage)
  })
_sym_db.RegisterMessage(NotifyVirtualDaaScoreChangedResponseMessage)

VirtualDaaScoreChangedNotificationMessage = _reflection.GeneratedProtocolMessageType('VirtualDaaScoreChangedNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.VirtualDaaScoreChangedNotificationMessage)
  })
_sym_db.RegisterMessage(VirtualDaaScoreChangedNotificationMessage)

NotifyPruningPointUTXOSetOverrideRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyPruningPointUTXOSetOverrideRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyPruningPointUTXOSetOverrideRequestMessage)
  })
_sym_db.RegisterMessage(NotifyPruningPointUTXOSetOverrideRequestMessage)

NotifyPruningPointUTXOSetOverrideResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyPruningPointUTXOSetOverrideResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyPruningPointUTXOSetOverrideResponseMessage)
  })
_sym_db.RegisterMessage(NotifyPruningPointUTXOSetOverrideResponseMessage)

PruningPointUTXOSetOverrideNotificationMessage = _reflection.GeneratedProtocolMessageType('PruningPointUTXOSetOverrideNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PruningPointUTXOSetOverrideNotificationMessage)
  })
_sym_db.RegisterMessage(PruningPointUTXOSetOverrideNotificationMessage)

StopNotifyingPruningPointUTXOSetOverrideRequestMessage = _reflection.GeneratedProtocolMessageType('StopNotifyingPruningPointUTXOSetOverrideRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.StopNotifyingPruningPointUTXOSetOverrideRequestMessage)
  })
_sym_db.RegisterMessage(StopNotifyingPruningPointUTXOSetOverrideRequestMessage)

StopNotifyingPruningPointUTXOSetOverrideResponseMessage = _reflection.GeneratedProtocolMessageType('StopNotifyingPruningPointUTXOSetOverrideResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.StopNotifyingPruningPointUTXOSetOverrideResponseMessage)
  })
_sym_db.RegisterMessage(StopNotifyingPruningPointUTXOSetOverrideResponseMessage)

BanRequestMessage = _reflection.GeneratedProtocolMessageType('BanRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _BANREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BanRequestMessage)
  })
_sym_db.RegisterMessage(BanRequestMessage)

BanResponseMessage = _reflection.GeneratedProtocolMessageType('BanResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _BANRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BanResponseMessage)
  })
_sym_db.RegisterMessage(BanResponseMessage)

UnbanRequestMessage = _reflection.GeneratedProtocolMessageType('UnbanRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _UNBANREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UnbanRequestMessage)
  })
_sym_db.RegisterMessage(UnbanRequestMessage)

UnbanResponseMessage = _reflection.GeneratedProtocolMessageType('UnbanResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _UNBANRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UnbanResponseMessage)
  })
_sym_db.RegisterMessage(UnbanResponseMessage)

GetInfoRequestMessage = _reflection.GeneratedProtocolMessageType('GetInfoRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETINFOREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetInfoRequestMessage)
  })
_sym_db.RegisterMessage(GetInfoRequestMessage)

GetInfoResponseMessage = _reflection.GeneratedProtocolMessageType('GetInfoResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETINFORESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetInfoResponseMessage)
  })
_sym_db.RegisterMessage(GetInfoResponseMessage)

EstimateNetworkHashesPerSecondRequestMessage = _reflection.GeneratedProtocolMessageType('EstimateNetworkHashesPerSecondRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.EstimateNetworkHashesPerSecondRequestMessage)
  })
_sym_db.RegisterMessage(EstimateNetworkHashesPerSecondRequestMessage)

EstimateNetworkHashesPerSecondResponseMessage = _reflection.GeneratedProtocolMessageType('EstimateNetworkHashesPerSecondResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.EstimateNetworkHashesPerSecondResponseMessage)
  })
_sym_db.RegisterMessage(EstimateNetworkHashesPerSecondResponseMessage)

NotifyNewBlockTemplateRequestMessage = _reflection.GeneratedProtocolMessageType('NotifyNewBlockTemplateRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyNewBlockTemplateRequestMessage)
  })
_sym_db.RegisterMessage(NotifyNewBlockTemplateRequestMessage)

NotifyNewBlockTemplateResponseMessage = _reflection.GeneratedProtocolMessageType('NotifyNewBlockTemplateResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NotifyNewBlockTemplateResponseMessage)
  })
_sym_db.RegisterMessage(NotifyNewBlockTemplateResponseMessage)

NewBlockTemplateNotificationMessage = _reflection.GeneratedProtocolMessageType('NewBlockTemplateNotificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _NEWBLOCKTEMPLATENOTIFICATIONMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NewBlockTemplateNotificationMessage)
  })
_sym_db.RegisterMessage(NewBlockTemplateNotificationMessage)

MempoolEntryByAddress = _reflection.GeneratedProtocolMessageType('MempoolEntryByAddress', (_message.Message,), {
  'DESCRIPTOR' : _MEMPOOLENTRYBYADDRESS,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.MempoolEntryByAddress)
  })
_sym_db.RegisterMessage(MempoolEntryByAddress)

GetMempoolEntriesByAddressesRequestMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntriesByAddressesRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntriesByAddressesRequestMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntriesByAddressesRequestMessage)

GetMempoolEntriesByAddressesResponseMessage = _reflection.GeneratedProtocolMessageType('GetMempoolEntriesByAddressesResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetMempoolEntriesByAddressesResponseMessage)
  })
_sym_db.RegisterMessage(GetMempoolEntriesByAddressesResponseMessage)

GetCoinSupplyRequestMessage = _reflection.GeneratedProtocolMessageType('GetCoinSupplyRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCOINSUPPLYREQUESTMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetCoinSupplyRequestMessage)
  })
_sym_db.RegisterMessage(GetCoinSupplyRequestMessage)

GetCoinSupplyResponseMessage = _reflection.GeneratedProtocolMessageType('GetCoinSupplyResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETCOINSUPPLYRESPONSEMESSAGE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GetCoinSupplyResponseMessage)
  })
_sym_db.RegisterMessage(GetCoinSupplyResponseMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/kaspanet/kaspad/protowire'
  _RPCERROR._serialized_start=24
  _RPCERROR._serialized_end=51
  _RPCBLOCK._serialized_start=54
  _RPCBLOCK._serialized_end=209
  _RPCBLOCKHEADER._serialized_start=212
  _RPCBLOCKHEADER._serialized_end=498
  _RPCBLOCKLEVELPARENTS._serialized_start=500
  _RPCBLOCKLEVELPARENTS._serialized_end=544
  _RPCBLOCKVERBOSEDATA._serialized_start=547
  _RPCBLOCKVERBOSEDATA._serialized_end=798
  _RPCTRANSACTION._serialized_start=801
  _RPCTRANSACTION._serialized_end=1061
  _RPCTRANSACTIONINPUT._serialized_start=1064
  _RPCTRANSACTIONINPUT._serialized_end=1262
  _RPCSCRIPTPUBLICKEY._serialized_start=1264
  _RPCSCRIPTPUBLICKEY._serialized_end=1326
  _RPCTRANSACTIONOUTPUT._serialized_start=1329
  _RPCTRANSACTIONOUTPUT._serialized_end=1488
  _RPCOUTPOINT._serialized_start=1490
  _RPCOUTPOINT._serialized_end=1541
  _RPCUTXOENTRY._serialized_start=1544
  _RPCUTXOENTRY._serialized_end=1673
  _RPCTRANSACTIONVERBOSEDATA._serialized_start=1675
  _RPCTRANSACTIONVERBOSEDATA._serialized_end=1791
  _RPCTRANSACTIONINPUTVERBOSEDATA._serialized_start=1793
  _RPCTRANSACTIONINPUTVERBOSEDATA._serialized_end=1825
  _RPCTRANSACTIONOUTPUTVERBOSEDATA._serialized_start=1827
  _RPCTRANSACTIONOUTPUTVERBOSEDATA._serialized_end=1921
  _GETCURRENTNETWORKREQUESTMESSAGE._serialized_start=1923
  _GETCURRENTNETWORKREQUESTMESSAGE._serialized_end=1956
  _GETCURRENTNETWORKRESPONSEMESSAGE._serialized_start=1958
  _GETCURRENTNETWORKRESPONSEMESSAGE._serialized_end=2053
  _SUBMITBLOCKREQUESTMESSAGE._serialized_start=2055
  _SUBMITBLOCKREQUESTMESSAGE._serialized_end=2145
  _SUBMITBLOCKRESPONSEMESSAGE._serialized_start=2148
  _SUBMITBLOCKRESPONSEMESSAGE._serialized_end=2347
  _SUBMITBLOCKRESPONSEMESSAGE_REJECTREASON._serialized_start=2289
  _SUBMITBLOCKRESPONSEMESSAGE_REJECTREASON._serialized_end=2347
  _GETBLOCKTEMPLATEREQUESTMESSAGE._serialized_start=2349
  _GETBLOCKTEMPLATEREQUESTMESSAGE._serialized_end=2420
  _GETBLOCKTEMPLATERESPONSEMESSAGE._serialized_start=2422
  _GETBLOCKTEMPLATERESPONSEMESSAGE._serialized_end=2546
  _NOTIFYBLOCKADDEDREQUESTMESSAGE._serialized_start=2548
  _NOTIFYBLOCKADDEDREQUESTMESSAGE._serialized_end=2580
  _NOTIFYBLOCKADDEDRESPONSEMESSAGE._serialized_start=2582
  _NOTIFYBLOCKADDEDRESPONSEMESSAGE._serialized_end=2652
  _BLOCKADDEDNOTIFICATIONMESSAGE._serialized_start=2654
  _BLOCKADDEDNOTIFICATIONMESSAGE._serialized_end=2721
  _GETPEERADDRESSESREQUESTMESSAGE._serialized_start=2723
  _GETPEERADDRESSESREQUESTMESSAGE._serialized_end=2755
  _GETPEERADDRESSESRESPONSEMESSAGE._serialized_start=2758
  _GETPEERADDRESSESRESPONSEMESSAGE._serialized_end=2968
  _GETPEERADDRESSESKNOWNADDRESSMESSAGE._serialized_start=2970
  _GETPEERADDRESSESKNOWNADDRESSMESSAGE._serialized_end=3021
  _GETSELECTEDTIPHASHREQUESTMESSAGE._serialized_start=3023
  _GETSELECTEDTIPHASHREQUESTMESSAGE._serialized_end=3057
  _GETSELECTEDTIPHASHRESPONSEMESSAGE._serialized_start=3059
  _GETSELECTEDTIPHASHRESPONSEMESSAGE._serialized_end=3156
  _GETMEMPOOLENTRYREQUESTMESSAGE._serialized_start=3158
  _GETMEMPOOLENTRYREQUESTMESSAGE._serialized_end=3261
  _GETMEMPOOLENTRYRESPONSEMESSAGE._serialized_start=3263
  _GETMEMPOOLENTRYRESPONSEMESSAGE._serialized_end=3372
  _GETMEMPOOLENTRIESREQUESTMESSAGE._serialized_start=3374
  _GETMEMPOOLENTRIESREQUESTMESSAGE._serialized_end=3465
  _GETMEMPOOLENTRIESRESPONSEMESSAGE._serialized_start=3467
  _GETMEMPOOLENTRIESRESPONSEMESSAGE._serialized_end=3580
  _MEMPOOLENTRY._serialized_start=3582
  _MEMPOOLENTRY._serialized_end=3675
  _GETCONNECTEDPEERINFOREQUESTMESSAGE._serialized_start=3677
  _GETCONNECTEDPEERINFOREQUESTMESSAGE._serialized_end=3713
  _GETCONNECTEDPEERINFORESPONSEMESSAGE._serialized_start=3716
  _GETCONNECTEDPEERINFORESPONSEMESSAGE._serialized_end=3845
  _GETCONNECTEDPEERINFOMESSAGE._serialized_start=3848
  _GETCONNECTEDPEERINFOMESSAGE._serialized_end=4068
  _ADDPEERREQUESTMESSAGE._serialized_start=4070
  _ADDPEERREQUESTMESSAGE._serialized_end=4131
  _ADDPEERRESPONSEMESSAGE._serialized_start=4133
  _ADDPEERRESPONSEMESSAGE._serialized_end=4194
  _SUBMITTRANSACTIONREQUESTMESSAGE._serialized_start=4196
  _SUBMITTRANSACTIONREQUESTMESSAGE._serialized_end=4298
  _SUBMITTRANSACTIONRESPONSEMESSAGE._serialized_start=4300
  _SUBMITTRANSACTIONRESPONSEMESSAGE._serialized_end=4394
  _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDREQUESTMESSAGE._serialized_start=4396
  _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDREQUESTMESSAGE._serialized_end=4490
  _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDRESPONSEMESSAGE._serialized_start=4492
  _NOTIFYVIRTUALSELECTEDPARENTCHAINCHANGEDRESPONSEMESSAGE._serialized_end=4585
  _VIRTUALSELECTEDPARENTCHAINCHANGEDNOTIFICATIONMESSAGE._serialized_start=4588
  _VIRTUALSELECTEDPARENTCHAINCHANGEDNOTIFICATIONMESSAGE._serialized_end=4773
  _GETBLOCKREQUESTMESSAGE._serialized_start=4775
  _GETBLOCKREQUESTMESSAGE._serialized_end=4842
  _GETBLOCKRESPONSEMESSAGE._serialized_start=4844
  _GETBLOCKRESPONSEMESSAGE._serialized_end=4942
  _GETSUBNETWORKREQUESTMESSAGE._serialized_start=4944
  _GETSUBNETWORKREQUESTMESSAGE._serialized_end=4995
  _GETSUBNETWORKRESPONSEMESSAGE._serialized_start=4997
  _GETSUBNETWORKRESPONSEMESSAGE._serialized_end=5082
  _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKREQUESTMESSAGE._serialized_start=5084
  _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKREQUESTMESSAGE._serialized_end=5196
  _ACCEPTEDTRANSACTIONIDS._serialized_start=5198
  _ACCEPTEDTRANSACTIONIDS._serialized_end=5282
  _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKRESPONSEMESSAGE._serialized_start=5285
  _GETVIRTUALSELECTEDPARENTCHAINFROMBLOCKRESPONSEMESSAGE._serialized_end=5508
  _GETBLOCKSREQUESTMESSAGE._serialized_start=5510
  _GETBLOCKSREQUESTMESSAGE._serialized_end=5604
  _GETBLOCKSRESPONSEMESSAGE._serialized_start=5606
  _GETBLOCKSRESPONSEMESSAGE._serialized_end=5727
  _GETBLOCKCOUNTREQUESTMESSAGE._serialized_start=5729
  _GETBLOCKCOUNTREQUESTMESSAGE._serialized_end=5758
  _GETBLOCKCOUNTRESPONSEMESSAGE._serialized_start=5760
  _GETBLOCKCOUNTRESPONSEMESSAGE._serialized_end=5868
  _GETBLOCKDAGINFOREQUESTMESSAGE._serialized_start=5870
  _GETBLOCKDAGINFOREQUESTMESSAGE._serialized_end=5901
  _GETBLOCKDAGINFORESPONSEMESSAGE._serialized_start=5904
  _GETBLOCKDAGINFORESPONSEMESSAGE._serialized_end=6178
  _RESOLVEFINALITYCONFLICTREQUESTMESSAGE._serialized_start=6180
  _RESOLVEFINALITYCONFLICTREQUESTMESSAGE._serialized_end=6246
  _RESOLVEFINALITYCONFLICTRESPONSEMESSAGE._serialized_start=6248
  _RESOLVEFINALITYCONFLICTRESPONSEMESSAGE._serialized_end=6325
  _NOTIFYFINALITYCONFLICTSREQUESTMESSAGE._serialized_start=6327
  _NOTIFYFINALITYCONFLICTSREQUESTMESSAGE._serialized_end=6366
  _NOTIFYFINALITYCONFLICTSRESPONSEMESSAGE._serialized_start=6368
  _NOTIFYFINALITYCONFLICTSRESPONSEMESSAGE._serialized_end=6445
  _FINALITYCONFLICTNOTIFICATIONMESSAGE._serialized_start=6447
  _FINALITYCONFLICTNOTIFICATIONMESSAGE._serialized_end=6512
  _FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE._serialized_start=6514
  _FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE._serialized_end=6586
  _SHUTDOWNREQUESTMESSAGE._serialized_start=6588
  _SHUTDOWNREQUESTMESSAGE._serialized_end=6612
  _SHUTDOWNRESPONSEMESSAGE._serialized_start=6614
  _SHUTDOWNRESPONSEMESSAGE._serialized_end=6676
  _GETHEADERSREQUESTMESSAGE._serialized_start=6678
  _GETHEADERSREQUESTMESSAGE._serialized_end=6759
  _GETHEADERSRESPONSEMESSAGE._serialized_start=6761
  _GETHEADERSRESPONSEMESSAGE._serialized_end=6842
  _NOTIFYUTXOSCHANGEDREQUESTMESSAGE._serialized_start=6844
  _NOTIFYUTXOSCHANGEDREQUESTMESSAGE._serialized_end=6897
  _NOTIFYUTXOSCHANGEDRESPONSEMESSAGE._serialized_start=6899
  _NOTIFYUTXOSCHANGEDRESPONSEMESSAGE._serialized_end=6971
  _UTXOSCHANGEDNOTIFICATIONMESSAGE._serialized_start=6974
  _UTXOSCHANGEDNOTIFICATIONMESSAGE._serialized_end=7107
  _UTXOSBYADDRESSESENTRY._serialized_start=7109
  _UTXOSBYADDRESSESENTRY._serialized_end=7235
  _STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE._serialized_start=7237
  _STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE._serialized_end=7297
  _STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE._serialized_start=7299
  _STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE._serialized_end=7378
  _GETUTXOSBYADDRESSESREQUESTMESSAGE._serialized_start=7380
  _GETUTXOSBYADDRESSESREQUESTMESSAGE._serialized_end=7434
  _GETUTXOSBYADDRESSESRESPONSEMESSAGE._serialized_start=7436
  _GETUTXOSBYADDRESSESRESPONSEMESSAGE._serialized_end=7560
  _GETBALANCEBYADDRESSREQUESTMESSAGE._serialized_start=7562
  _GETBALANCEBYADDRESSREQUESTMESSAGE._serialized_end=7614
  _GETBALANCEBYADDRESSRESPONSEMESSAGE._serialized_start=7616
  _GETBALANCEBYADDRESSRESPONSEMESSAGE._serialized_end=7706
  _GETBALANCESBYADDRESSESREQUESTMESSAGE._serialized_start=7708
  _GETBALANCESBYADDRESSESREQUESTMESSAGE._serialized_end=7765
  _BALANCESBYADDRESSENTRY._serialized_start=7767
  _BALANCESBYADDRESSENTRY._serialized_end=7862
  _GETBALANCESBYADDRESSESRESPONSEMESSAGE._serialized_start=7865
  _GETBALANCESBYADDRESSESRESPONSEMESSAGE._serialized_end=7993
  _GETVIRTUALSELECTEDPARENTBLUESCOREREQUESTMESSAGE._serialized_start=7995
  _GETVIRTUALSELECTEDPARENTBLUESCOREREQUESTMESSAGE._serialized_end=8044
  _GETVIRTUALSELECTEDPARENTBLUESCORERESPONSEMESSAGE._serialized_start=8046
  _GETVIRTUALSELECTEDPARENTBLUESCORERESPONSEMESSAGE._serialized_end=8152
  _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDREQUESTMESSAGE._serialized_start=8154
  _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDREQUESTMESSAGE._serialized_end=8213
  _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDRESPONSEMESSAGE._serialized_start=8215
  _NOTIFYVIRTUALSELECTEDPARENTBLUESCORECHANGEDRESPONSEMESSAGE._serialized_end=8312
  _VIRTUALSELECTEDPARENTBLUESCORECHANGEDNOTIFICATIONMESSAGE._serialized_start=8314
  _VIRTUALSELECTEDPARENTBLUESCORECHANGEDNOTIFICATIONMESSAGE._serialized_end=8412
  _NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE._serialized_start=8414
  _NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE._serialized_end=8458
  _NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE._serialized_start=8460
  _NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE._serialized_end=8542
  _VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE._serialized_start=8544
  _VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE._serialized_end=8612
  _NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE._serialized_start=8614
  _NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE._serialized_end=8663
  _NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE._serialized_start=8665
  _NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE._serialized_end=8752
  _PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE._serialized_start=8754
  _PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE._serialized_end=8802
  _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE._serialized_start=8804
  _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE._serialized_end=8860
  _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE._serialized_start=8862
  _STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE._serialized_end=8956
  _BANREQUESTMESSAGE._serialized_start=8958
  _BANREQUESTMESSAGE._serialized_end=8989
  _BANRESPONSEMESSAGE._serialized_start=8991
  _BANRESPONSEMESSAGE._serialized_end=9048
  _UNBANREQUESTMESSAGE._serialized_start=9050
  _UNBANREQUESTMESSAGE._serialized_end=9083
  _UNBANRESPONSEMESSAGE._serialized_start=9085
  _UNBANRESPONSEMESSAGE._serialized_end=9144
  _GETINFOREQUESTMESSAGE._serialized_start=9146
  _GETINFOREQUESTMESSAGE._serialized_end=9169
  _GETINFORESPONSEMESSAGE._serialized_start=9172
  _GETINFORESPONSEMESSAGE._serialized_end=9333
  _ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE._serialized_start=9335
  _ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE._serialized_end=9420
  _ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE._serialized_start=9422
  _ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE._serialized_end=9538
  _NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE._serialized_start=9540
  _NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE._serialized_end=9578
  _NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE._serialized_start=9580
  _NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE._serialized_end=9656
  _NEWBLOCKTEMPLATENOTIFICATIONMESSAGE._serialized_start=9658
  _NEWBLOCKTEMPLATENOTIFICATIONMESSAGE._serialized_end=9695
  _MEMPOOLENTRYBYADDRESS._serialized_start=9697
  _MEMPOOLENTRYBYADDRESS._serialized_end=9823
  _GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE._serialized_start=9825
  _GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE._serialized_end=9946
  _GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE._serialized_start=9949
  _GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE._serialized_end=10082
  _GETCOINSUPPLYREQUESTMESSAGE._serialized_start=10084
  _GETCOINSUPPLYREQUESTMESSAGE._serialized_end=10113
  _GETCOINSUPPLYRESPONSEMESSAGE._serialized_start=10115
  _GETCOINSUPPLYRESPONSEMESSAGE._serialized_end=10226
# @@protoc_insertion_point(module_scope)



from kaspy.utils.version_comparer import version as ver
from . import __version__, __name__

#### KASPAD defines #####

# Available services:
RPC_SERVICE = 'RPC' # use _SERVICE suffix, RPC is defined in kaspy.proros.messages_pb_grpc.py
P2P_SERVICE = 'P2P' # use _SERVICE suffix, P2P is defined in kaspy.proros.messages_pb_grpc.py


# Subnetworks:

## Subnetwork names:
MAINNET = 'mainnet'
TESTNET = 'testnet'
SIMNET = 'simnet'
DEVNET = 'devnet'

## Default ports for services:
RPC_DEF_PORTS = {
    MAINNET: 16110,
    TESTNET: 16210, 
    SIMNET: 16510,
    DEVNET: 16610,
}

P2P_DEF_PORTS = {
    MAINNET : 16111,
    TESTNET : 16211, 
    DEVNET : 16611,
    SIMNET : 16511
}


## Available subnetworks:
SUBNETWORKS = (MAINNET, TESTNET, DEVNET, SIMNET) #Devnet and Simnet are NotImplmented

# Kaspad, latest version:
LATEST_KASPAD_VERSION = ver(0, 11, 9)

LATEST_PROTOCOL_VERSION = ver(3,0,0)

#### For client #####

CONNECTED = 'connected' #connection is open for send / recv
DISCONNECTED = 'disconnected' # disables send / recv, waits for queued send / recv data to pass, keeps spin thread waiting in background for possible reconnection
CLOSED = 'closed' # terminates the connection immediatly, does not wait for queued data, kills spin thread. does not expect a reconnection attempt. 

ClIENT_STATES = (CONNECTED, DISCONNECTED, CLOSED) 

### for p2p usage, I think I need ###
USER_AGENT = f'{__version__} {__name__}'